@@ -1,7 +1,6 @@
 from azure.storage.blob import BlockBlobService, ContentSettings
 
-from foqus.configuration import *
-from foqus.database import logger
+from foqus.aws_configuration import *
 
 from io import BytesIO
 
@@ -64,8 +63,21 @@ def list_parquet_files():
     parquet_files = []
     try:
         for blob in generator:
-            if blob.name.endswith('.parquet'):
-                parquet_files.append(blob.name)
+            if blob.name.endswith('.parquet') and AZURE_VECTORS_PATH in blob.name:
+                try:
+                    project = blob.name.split('/')[-3]
+                    customer_name = blob.name.split('/')[-4]
+                    customer_type = blob.name.split('/')[-5]
+                    status = db.get_status_project(STATUS_PROJECT_TABLE, customer_name, customer_type,
+                                                   'similars', project)
+                    if status and status[0] == 2:
+                        parquet_files.append(blob.name)
+                    else:
+                        logger.info('Status Project not 2 %s %s' % (project, status))
+                        continue
+                except Exception as e:
+                    logger.info("Vector not loaded %s" %e)
+
     except Exception as e:
         logger.error("Exception in listing parquet files ..." + str(e))
     return parquet_files
@@ -201,4 +213,25 @@ def copy_azure_file(blob_name, copy_from_container, copy_to_container):
         #for move the file use this line
         blob_service.delete_blob(copy_from_container, blob_name)
     except Exception as e:
-        logger.info('blob_name  %s not found error is %s' % (blob_name, e))
\ No newline at end of file
+        logger.info('blob_name  %s not found error is %s' % (blob_name, e))
+
+
+def copy_azure_files(blob_name):
+
+        blob_service = BlockBlobService(account_name=AZURE_ACCOUNT_NAME, account_key=AZURE_ACCOUNT_KEY)
+        copy_from_container = 'backup'
+        copy_to_container = 'buckupdev'
+
+        blob_url = blob_service.make_blob_url(copy_from_container, blob_name)
+        # blob_url:https://demostorage.blob.core.windows.net/image-container/pretty.jpg
+
+        blob_service.copy_blob(copy_to_container, blob_name, blob_url)
+
+        #for move the file use this line
+        blob_service.delete_blob(copy_from_container, blob_name)
+
+
+def copying_files():
+    for blob_name in list_repository_files('backup/devBUCUP/'):
+        logger.info('====> copying %s' %blob_name)
+        copy_azure_files(blob_name)
\ No newline at end of file
