@@ -374,7 +374,7 @@ def download_or_remove(urls, each_url_product, customer_name=None, customer_type
             logger.info("File exists but size is 0... Download again!")
             start = time.process_time()
             download_resized_image(url, fichier)
-            print("*** download time taken" + str(time.process_time() - start))
+            logger.info("*** download time taken" + str(time.process_time() - start))
         else:
             logger.info("File doesn't exist... Downloading...")
             download_resized_image(url, fichier)
@@ -388,17 +388,6 @@ def download_or_remove(urls, each_url_product, customer_name=None, customer_type
                 file_azure = input_azure + fichier.split('/')[-2] + '/' + fichier.split('/')[-1]
             upload_file_into_azure(file_azure, fichier)
 
-        # while get_file_hash(fichier) != hash_file:
-        #     logger.warning("File exists but hash is incorrect... Download again!")
-        #     hash_file = get_remote_file_hash(url)
-        #     download_resized_image(url, fichier)
-        #     if USE_AWS:
-        #         upload_file_into_s3(fichier, input_s3 + fichier.split('/')[-2] + '/')
-
-        if get_file_hash(fichier) != hash_file:
-            logger.error("File wasn't downloaded correctly! " + fichier)
-        else:
-            logger.info("File was successfully downloaded (hash OK) >>> File path: " + fichier)
         hash_files = hash_files + filename + " "
         data_product = db.get_product_details(replace_special_caractere(customer_name).replace(' ', '_'),
                                               each_url_product,
@@ -460,17 +449,7 @@ def safe_download(url, file_path):
     else:
         logger.info("File downloaded successfully.")
 
-    retries = 0
-    while get_file_hash(file_path) != hash_file and retries < MAX_DOWNLOAD_FILE_RETRIES:
-        logger.warning("File exists but hash is incorrect... Download again!")
-        hash_file = get_remote_file_hash(url)
-        download(url, file_path)
-        retries += 1
-
-    if get_file_hash(file_path) != hash_file:
-        logger.error("File wasn't downloaded correctly! " + file_path)
-    else:
-        logger.info("File was successfully downloaded (hash OK) >>> File path: " + file_path)
+    logger.info("File was successfully downloaded (hash OK) >>> File path: " + file_path)
 
 
 def resize_images(target=TARGET_RESOLUTION, customer_name=None, customer_type=None,project_name=None):
