@@ -4,7 +4,6 @@ from foqus.commons import download
 from foqus.customers import *
 from foqus.pipline_cutomise import *
 from foqus.request_api import APIFoqus
-from foqus.server_apis import classfication_after_similars
 from six.moves import http_client
 
 from urllib.parse import urlparse
@@ -38,7 +37,7 @@ def reset_keras():
     sess.close()
     sess = get_session()
 
-    print(gc.collect())  # if it's done something you should see a number being outputted
+    logger.info(gc.collect())  # if it's done something you should see a number being outputted
 
     # use the same config as you used to create the session
     config = tensorflow.ConfigProto()
@@ -118,8 +117,11 @@ def delta_retrieve_json(customer_name, customer_type, project_name):
     else:
         last_json = {customer_name + "_" + customer_type: []}
         before_last_json = {customer_name + "_" + customer_type: []}
-
-    difference = diff(before_last_json, last_json)
+    try:
+        difference = diff(before_last_json, last_json)
+    except Exception as e:
+        logger.error("Error_diff %s" %e)
+        difference = {}
     if before_last_json[customer_name + "_" + customer_type] != [] and difference != {} \
             and difference[customer_name + '_' + customer_type]:
         for kcat, cat in difference[customer_name + '_' + customer_type].items():
@@ -267,36 +269,42 @@ def image_extension(image_url):
 
 
 def max_nb_images(path):
-    list_nbrs = []
-    for j in os.listdir(path):
-        for k in os.listdir(str(path) + "/" + str(j)):
-            ext = imghdr.what(str(path) + "/" + str(j) + "/" + str(k))
-            if (ext == 'png' and k.split(".")[1] in ['jpg', 'jpeg', 'JPG', 'JPEG']) or \
-                    (ext in ['jpeg', 'jpg'] and k.split('.')[1] in ['png', 'PNG']) or (ext is None):
-                os.remove(str(path) + "/" + str(j) + "/" + str(k))
-                logger.info("Deleting_image as it contains png encoding - " + str(path) + "/" + str(j) + "/" + str(k))
-        list_nbrs.append(len(os.listdir(str(path) + "/" + str(j))))
-    return max(list_nbrs)
-
+    try:
+        list_nbrs = []
+        for j in os.listdir(path):
+            for k in os.listdir(str(path) + "/" + str(j)):
+                ext = imghdr.what(str(path) + "/" + str(j) + "/" + str(k))
+                if (ext == 'png' and k.split(".")[1] in ['jpg', 'jpeg', 'JPG', 'JPEG']) or \
+                        (ext in ['jpeg', 'jpg'] and k.split('.')[1] in ['png', 'PNG']) or (ext is None):
+                    os.remove(str(path) + "/" + str(j) + "/" + str(k))
+                    logger.info("Deleting_image as it contains png encoding - " + str(path) + "/" + str(j) + "/" + str(k))
+            list_nbrs.append(len(os.listdir(str(path) + "/" + str(j))))
+        return max(list_nbrs)
+    except Exception as e:
+        logger.error(e)
 
 def verif_folder_less_twenty(path):
-    image_ext = ['.jpg', '.png', '.jpeg', '.JPG', '.PNG', '.JPEG']
-    folder_less_20 = []
-    max_nb = max_nb_images(path)
-    if max_nb < 20:
-        max_nb = 20
-    for j in os.listdir(path):
-        x = 0
-        for i in os.listdir(str(path) + "/" + str(j)):
-            if os.path.splitext(i)[1] in image_ext:
-                x = x + 1
-        if x == 0 :
-            shutil.rmtree(str(path) + "/" + str(j))
-            logger.info("Deletin Empty folder : " + str(path) + "/" + str(j))
-        elif (x <= 20 or x < max_nb):
-            logger.info("WARNING: Folder has less images : " + str(j).split('/')[-1])
-            folder_less_20.append(str(j).split('/')[-1])
-    return folder_less_20, max_nb
+    try:
+        image_ext = ['.jpg', '.png', '.jpeg', '.JPG', '.PNG', '.JPEG']
+        folder_less_20 = []
+        max_nb = max_nb_images(path)
+        if max_nb < 50:
+            max_nb = 50
+        #else max nb va prendre le max automatiquement
+        for j in os.listdir(path):
+            x = 0
+            for i in os.listdir(str(path) + "/" + str(j)):
+                if os.path.splitext(i)[1] in image_ext:
+                    x = x + 1
+            if x == 0 :
+                shutil.rmtree(str(path) + "/" + str(j))
+                logger.info("Deletin Empty folder : " + str(path) + "/" + str(j))
+            elif (x <= 50 or x < max_nb):
+                logger.info("WARNING: Folder has less images : " + str(j).split('/')[-1])
+                folder_less_20.append(str(j).split('/')[-1])
+        return folder_less_20, max_nb
+    except Exception as e:
+        logger.error(e)
 
 
 def generate_more_images(training_path, folders, max_nb):
@@ -356,6 +364,10 @@ def fill_prediction_table(path_file_Final, customer_type, customer_name, custome
         db.add_prediction_table(table_name, row_values, principal_categorie)
 
 
+def classification_similars(customer_name, customer_type, project_name):
+    api.apipost("classification_similars", customer_name, customer_type, project_name)
+
+
 def process_customer_stream_from_json(json_path, customer_name, customer_type, project_name):
     json_path = delta_retrieve_json(customer_name, customer_type, project_name)
     request_post = api.apipost('retrieve_images_json', customer_name, customer_type, project_name, json_path)
@@ -363,9 +375,26 @@ def process_customer_stream_from_json(json_path, customer_name, customer_type, p
     response = response_text['response']
     deleted_image = response_text['deleted_images']
     if int(response) != 0:
-        if generate_similarity_vector(customer_name, customer_type, deleted_image, project_name):
-            user_apikey = db.get_apikey_from_customer(customer_name)[0]
-            classfication_after_similars(user_apikey, customer_name, customer_type, project_name)
+        path_out = OUTPUT_PATH + customer_type + '/' + customer_name + '/images/' + project_name + '/'
+        try:
+            import os
+            folders = next(os.walk(path_out))[1]
+        except Exception as e:
+            folders = []
+            logger.error("Folders_training_similars %s" % e)
+        if len(folders) > 0:
+            try:
+                projects = db.get_training_detalis(STATUS_PROJECT_TABLE, customer_name, customer_type, project_name,
+                                                   'classification')
+                train_details = json.loads(projects[0])
+            except :
+                logger.info("First time training for project %s client %s with type %s" % (project_name, customer_name, customer_type))
+                train_details = {}
+            if set(train_details.get('categories', [])) != set(deleted_image.keys()):
+                    logger.info("Categories Not the same, repeating classification process")
+                    classification_similars(customer_name, customer_type, project_name)
+
+        generate_similarity_vector(customer_name, customer_type, deleted_image, project_name)
 
 
 def process_customer_stream_cms(json_path, customer_name, customer_type, project_name):
@@ -422,7 +451,3 @@ def text_training_retrieve_json(excel_path, customer_name, customer_type, custom
 
     api.apipost(operation, customer_name, customer_type, project_name, excel_path, customer_universe)
 
-
-def classification_similars(customer_name, customer_type, project_name):
-    api.apipost("classification_similars", customer_name, customer_type, project_name)
-
